@@ -4,6 +4,7 @@
 from lusid.api.abor_api import AborApi
 from lusid.api.abor_configuration_api import AborConfigurationApi
 from lusid.api.address_key_definition_api import AddressKeyDefinitionApi
+from lusid.api.aggregated_returns_api import AggregatedReturnsApi
 from lusid.api.aggregation_api import AggregationApi
 from lusid.api.allocations_api import AllocationsApi
 from lusid.api.amortisation_rule_sets_api import AmortisationRuleSetsApi
@@ -19,6 +20,7 @@ from lusid.api.corporate_action_sources_api import CorporateActionSourcesApi
 from lusid.api.counterparties_api import CounterpartiesApi
 from lusid.api.custom_entities_api import CustomEntitiesApi
 from lusid.api.custom_entity_definitions_api import CustomEntityDefinitionsApi
+from lusid.api.custom_data_models_api import CustomDataModelsApi
 from lusid.api.custom_entity_types_api import CustomEntityTypesApi
 from lusid.api.cut_label_definitions_api import CutLabelDefinitionsApi
 from lusid.api.data_types_api import DataTypesApi
@@ -29,9 +31,12 @@ from lusid.api.fee_types_api import FeeTypesApi
 from lusid.api.fund_configuration_api import FundConfigurationApi
 from lusid.api.funds_api import FundsApi
 from lusid.api.group_reconciliations_api import GroupReconciliationsApi
+from lusid.api.identifier_definitions_api import IdentifierDefinitionsApi
 from lusid.api.instrument_event_types_api import InstrumentEventTypesApi
 from lusid.api.instrument_events_api import InstrumentEventsApi
 from lusid.api.instruments_api import InstrumentsApi
+from lusid.api.investment_accounts_api import InvestmentAccountsApi
+from lusid.api.investor_records_api import InvestorRecordsApi
 from lusid.api.legacy_compliance_api import LegacyComplianceApi
 from lusid.api.legal_entities_api import LegalEntitiesApi
 from lusid.api.order_graph_api import OrderGraphApi
@@ -51,6 +56,7 @@ from lusid.api.reconciliations_api import ReconciliationsApi
 from lusid.api.reference_lists_api import ReferenceListsApi
 from lusid.api.reference_portfolio_api import ReferencePortfolioApi
 from lusid.api.relation_definitions_api import RelationDefinitionsApi
+from lusid.api.relational_dataset_definition_api import RelationalDatasetDefinitionApi
 from lusid.api.relations_api import RelationsApi
 from lusid.api.relationship_definitions_api import RelationshipDefinitionsApi
 from lusid.api.relationships_api import RelationshipsApi
@@ -59,6 +65,7 @@ from lusid.api.scopes_api import ScopesApi
 from lusid.api.scripted_translation_api import ScriptedTranslationApi
 from lusid.api.search_api import SearchApi
 from lusid.api.sequences_api import SequencesApi
+from lusid.api.simple_position_portfolios_api import SimplePositionPortfoliosApi
 from lusid.api.staged_modifications_api import StagedModificationsApi
 from lusid.api.staging_rule_set_api import StagingRuleSetApi
 from lusid.api.structured_result_data_api import StructuredResultDataApi
@@ -68,6 +75,7 @@ from lusid.api.timelines_api import TimelinesApi
 from lusid.api.transaction_configuration_api import TransactionConfigurationApi
 from lusid.api.transaction_fees_api import TransactionFeesApi
 from lusid.api.transaction_portfolios_api import TransactionPortfoliosApi
+from lusid.api.transfer_agency_api import TransferAgencyApi
 from lusid.api.translation_api import TranslationApi
 from lusid.api.workspace_api import WorkspaceApi
 
@@ -76,6 +84,7 @@ __all__ = [
     "AborApi",
     "AborConfigurationApi",
     "AddressKeyDefinitionApi",
+    "AggregatedReturnsApi",
     "AggregationApi",
     "AllocationsApi",
     "AmortisationRuleSetsApi",
@@ -91,6 +100,7 @@ __all__ = [
     "CounterpartiesApi",
     "CustomEntitiesApi",
     "CustomEntityDefinitionsApi",
+    "CustomDataModelsApi",
     "CustomEntityTypesApi",
     "CutLabelDefinitionsApi",
     "DataTypesApi",
@@ -101,9 +111,12 @@ __all__ = [
     "FundConfigurationApi",
     "FundsApi",
     "GroupReconciliationsApi",
+    "IdentifierDefinitionsApi",
     "InstrumentEventTypesApi",
     "InstrumentEventsApi",
     "InstrumentsApi",
+    "InvestmentAccountsApi",
+    "InvestorRecordsApi",
     "LegacyComplianceApi",
     "LegalEntitiesApi",
     "OrderGraphApi",
@@ -123,6 +136,7 @@ __all__ = [
     "ReferenceListsApi",
     "ReferencePortfolioApi",
     "RelationDefinitionsApi",
+    "RelationalDatasetDefinitionApi",
     "RelationsApi",
     "RelationshipDefinitionsApi",
     "RelationshipsApi",
@@ -131,6 +145,7 @@ __all__ = [
     "ScriptedTranslationApi",
     "SearchApi",
     "SequencesApi",
+    "SimplePositionPortfoliosApi",
     "StagedModificationsApi",
     "StagingRuleSetApi",
     "StructuredResultDataApi",
@@ -140,6 +155,7 @@ __all__ = [
     "TransactionConfigurationApi",
     "TransactionFeesApi",
     "TransactionPortfoliosApi",
+    "TransferAgencyApi",
     "TranslationApi",
     "WorkspaceApi"
 ]
